linreg-class: A class for linear regression with many methods for...

Description Fields

Description

A class for linear regression with many methods for corresponding values calculations

Fields

y

vector The orginial labels of observations in data

X

matrix The features of all observations in data

beta

vector The coefficients in the sample

y_lb

matrix The estimated labels

x_lb

matrix The standard errors between orginial and estimated labels

dof

numeric The degree of freedom of data

var_rv

numeric The residual variance

var_rcf

matrix The variance of the regression coefficients

t_vcf

vector The t-values for each coefficient

p_vcf

vector The p-values for each coefficient

formula

character The formula used in the model

data

data.frame The sample data


mubarak27/lab4g26 documentation built on Nov. 5, 2019, 2:54 p.m.