A class for linear regression with many methods for corresponding values calculations
yvector The orginial labels of observations in data
Xmatrix The features of all observations in data
betavector The coefficients in the sample
y_lbmatrix The estimated labels
x_lbmatrix The standard errors between orginial and estimated labels
dofnumeric The degree of freedom of data
var_rvnumeric The residual variance
var_rcfmatrix The variance of the regression coefficients
t_vcfvector The t-values for each coefficient
p_vcfvector The p-values for each coefficient
formulacharacter The formula used in the model
datadata.frame The sample data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.